@@ -208,6 +208,10 @@ struct FastqParams final : CmnOptAndAccessions
 
     }
 
+    bool preferNoQual() const override {
+        return !fasta.isEmpty();
+    }
+
     std::ostream &show(std::ostream &ss) const override
     {
         if ( !accession_replacement.isEmpty() )  ss << "acc-replace : " << accession_replacement << std::endl;
@@ -364,13 +368,6 @@ struct FastqParams final : CmnOptAndAccessions
             if (realpath.executable())
                 return ToolExec::run(TOOL_NAME, realpath.fullpath(), theirArgv0, *this, accessions);
         }
-#if DEBUG || _DEBUGGING
-		{	// look for the "official" name not the -orig; TODO: remove when Make creates symlinks
-			auto const realpath = what.toolpath.getPathFor(TOOL_NAME);
-            if (realpath.executable())
-                return ToolExec::run(TOOL_NAME, realpath.fullpath(), theirArgv0, *this, accessions);
-        }
-#endif
         throw std::runtime_error(TOOL_NAME " was not found or is not executable.");
     }
 
