@@ -49,8 +49,9 @@ extern "C" {
 
 rc_t execute_lookup_production( KDirectory * dir,
                                 const VDBManager * vdb_mgr,
-                                const char * accession,
-                                struct background_vector_merger * merger,
+                                const char * accession_short,
+                                const char * accession_path,
+                                struct background_vector_merger_t * merger,
                                 size_t cursor_cache,
                                 size_t buf_size,
                                 size_t mem_limit,
