@@ -25,7 +25,9 @@
 */
 
 #include <kfg/kfg-priv.h> /* KConfigFixMainResolverCgiNode */
+
 #include <klib/printf.h> /* string_printf */
+#include <klib/strings.h> /* SDL_CGI */
 
 #include "util.hpp" // CStdIn
 
@@ -284,17 +286,54 @@ rc_t CKDirectory::CreateNonExistingDir(const CString &path,
     return rc;
 }
 
-rc_t CKConfig::Commit(void) const {
+CKConfig::CKConfig(bool verbose)
+    : m_Self(NULL), m_Updated(false)
+    , m_RepositoryRemoteAuxDisabled ("repository/remote/aux/NCBI/disabled")
+    , m_RepositoryRemoteMainDisabled("repository/remote/main/CGI/disabled")
+    , m_RepositoryUserRoot          ("repository/user/main/public/root")
+{
+    if (verbose)
+        OUTMSG(("loading configuration... "));
+    rc_t rc = KConfigMakeLocal(&m_Self, NULL);
+    if (rc == 0) {
+        if (verbose)
+            OUTMSG(("ok\n"));
+    }
+    else {
+        if (verbose)
+            OUTMSG(("failed\n"));
+        throw rc;
+    }
+}
+
+rc_t CKConfig::Commit(void)
+{
     if (!m_Updated) {
         return 0;
     }
 
-    return KConfigCommit(m_Self);
+    rc_t rc = KConfigCommit(m_Self);
+    if ( rc == 0 )
+    {
+        m_Updated = false;
+    }
+    return rc;
 }
 
 rc_t CKConfig::CreateRemoteRepositories(bool fix) {
-    rc_t rc = UpdateNode("/repository/remote/main/CGI/resolver-cgi",
-        "https://www.ncbi.nlm.nih.gov/Traces/names/names.fcgi");
+    bool updated = NodeExists("/repository_remote/CGI/resolver-cgi/trace");
+
+    rc_t rc = 0;
+
+    {
+        const string name("/repository/remote/main/CGI/resolver-cgi");
+        if (!updated || !NodeExists(name)) {
+            rc_t r2 = UpdateNode(name,
+                "https://trace.ncbi.nlm.nih.gov/Traces/names/names.fcgi");
+            if (r2 != 0 && rc == 0)
+                rc = r2;
+        }
+    }
 
     if (fix) {
         const string name("/repository/remote/main/CGI/disabled");
@@ -306,10 +345,14 @@ rc_t CKConfig::CreateRemoteRepositories(bool fix) {
         }
     }
 
-    rc_t r2 = UpdateNode("/repository/remote/protected/CGI/resolver-cgi",
-        "https://www.ncbi.nlm.nih.gov/Traces/names/names.fcgi");
-    if (r2 != 0 && rc == 0) {
-        rc = r2;
+    {
+        const string name("/repository/remote/protected/CGI/resolver-cgi");
+        if (!updated || !NodeExists(name)) {
+            rc_t r2 = UpdateNode(name,
+                "https://trace.ncbi.nlm.nih.gov/Traces/names/names.fcgi");
+            if (r2 != 0 && rc == 0)
+                rc = r2;
+        }
     }
 
     if (fix) {
@@ -322,6 +365,24 @@ rc_t CKConfig::CreateRemoteRepositories(bool fix) {
         }
     }
 
+    {
+        const string name("/repository/remote/main/SDL.2/resolver-cgi");
+        if (!NodeExists(name)) {
+            rc_t r2 = UpdateNode(name, SDL_CGI);
+            if (r2 != 0 && rc == 0)
+                rc = r2;
+        }
+    }
+
+    {
+        const string name("/repository/remote/protected/SDL.2/resolver-cgi");
+        if (!NodeExists(name)) {
+            rc_t r2 = UpdateNode(name, SDL_CGI);
+            if (r2 != 0 && rc == 0)
+                rc = r2;
+        }
+    }
+
     return rc;
 }
 
@@ -343,14 +404,20 @@ rc_t CKConfig::CreateUserRepository(string repoName, bool fix) {
     string repoNode(s.str());
     string name(repoNode + "/root");
 
+    rc_t rc = 0;
+    /* create all nodes but root;
     bool toFix = true;
     if (fix)
         toFix = !NodeExists(name);
-
-    rc_t rc = 0;
     if (toFix)
         rc = UpdateNode(name, (root + "/public").c_str());
 
+    {
+        rc_t r2 = UpdateNode(repoNode + "/cache-enabled", "true");
+        if (r2 != 0 && rc == 0)
+            rc = r2;
+    } */
+
     {
         string name ( repoNode + "/apps/file/volumes/flat" );
         if ( ! NodeExists ( name ) ) {
@@ -368,15 +435,25 @@ rc_t CKConfig::CreateUserRepository(string repoName, bool fix) {
         }
     }
 
-    {
-        rc_t r2 = UpdateNode ( repoNode + "/cache-enabled", "true" );
-        if ( r2 != 0 && rc == 0 )
-            rc = r2;
-    }
-
     if ( repoName != "public" )
         return rc;
 
+    {
+        string name(repoNode + "/apps/sraPileup/volumes/withExtFlat");
+        if (!NodeExists(name)) {
+            rc_t r2 = UpdateNode(name, "sra");
+            if (r2 != 0 && rc == 0)
+                rc = r2;
+        }
+    }
+    {
+        string name(repoNode + "/apps/sraRealign/volumes/withExtFlat");
+        if (!NodeExists(name)) {
+            rc_t r2 = UpdateNode(name, "sra");
+            if (r2 != 0 && rc == 0)
+                rc = r2;
+        }
+    }
     {
         string name ( repoNode + "/apps/nakmer/volumes/nakmerFlat" );
         if ( ! NodeExists ( name ) ) {
@@ -480,13 +557,14 @@ void CKConfig::Reload(bool verbose) {
     m_Self = NULL;
 
     if (rc == 0) {
-        rc = KConfigMake(&m_Self, NULL);
+        rc = KConfigMakeLocal(&m_Self, NULL);
     }
 
     if (rc == 0) {
         if (verbose) {
             OUTMSG(("ok\n"));
         }
+        m_Updated = false;
     }
     else {
         if (verbose) {
@@ -867,7 +945,7 @@ rc_t CRemoteRepository::Fix(CKConfig &kfg, bool disable, bool verbose) {
 
     if (Is("main")) {
         m_ResolverCgi
-            = "https://www.ncbi.nlm.nih.gov/Traces/names/names.fcgi";
+            = "https://trace.ncbi.nlm.nih.gov/Traces/names/names.fcgi";
         ClearApps();
     }
     else {
@@ -1100,7 +1178,7 @@ void CRemoteRepositories::Fix(CKConfig &kfg, bool disable, bool verbose) {
     }
 
     const string cgi
-        ("https://www.ncbi.nlm.nih.gov/Traces/names/names.fcgi");
+        ("https://trace.ncbi.nlm.nih.gov/Traces/names/names.fcgi");
     if (main == NULL) {
         main = new CRemoteRepository("main", "CGI", cgi);
         main->Fix(kfg, disable);
